# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from cryptoapis.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from cryptoapis.model.add_tokens_to_existing_from_address_r import AddTokensToExistingFromAddressR
from cryptoapis.model.add_tokens_to_existing_from_address_rb import AddTokensToExistingFromAddressRB
from cryptoapis.model.add_tokens_to_existing_from_address_rb_data import AddTokensToExistingFromAddressRBData
from cryptoapis.model.add_tokens_to_existing_from_address_rb_data_item import AddTokensToExistingFromAddressRBDataItem
from cryptoapis.model.add_tokens_to_existing_from_address_rb_token_data import AddTokensToExistingFromAddressRBTokenData
from cryptoapis.model.add_tokens_to_existing_from_address_rb_token_data_bitcoin_omni_token import AddTokensToExistingFromAddressRBTokenDataBitcoinOmniToken
from cryptoapis.model.add_tokens_to_existing_from_address_rb_token_data_ethereum_erc20_token import AddTokensToExistingFromAddressRBTokenDataEthereumErc20Token
from cryptoapis.model.add_tokens_to_existing_from_address_r_data import AddTokensToExistingFromAddressRData
from cryptoapis.model.add_tokens_to_existing_from_address_ri import AddTokensToExistingFromAddressRI
from cryptoapis.model.add_tokens_to_existing_from_address_rits import AddTokensToExistingFromAddressRITS
from cryptoapis.model.add_tokens_to_existing_from_address_ritsbot import AddTokensToExistingFromAddressRITSBOT
from cryptoapis.model.add_tokens_to_existing_from_address_ritseet import AddTokensToExistingFromAddressRITSEET
from cryptoapis.model.address_coins_transaction_confirmed import AddressCoinsTransactionConfirmed
from cryptoapis.model.address_coins_transaction_confirmed_data import AddressCoinsTransactionConfirmedData
from cryptoapis.model.address_coins_transaction_confirmed_data_item import AddressCoinsTransactionConfirmedDataItem
from cryptoapis.model.address_coins_transaction_confirmed_data_item_mined_in_block import AddressCoinsTransactionConfirmedDataItemMinedInBlock
from cryptoapis.model.address_coins_transaction_confirmed_each_confirmation import AddressCoinsTransactionConfirmedEachConfirmation
from cryptoapis.model.address_coins_transaction_confirmed_each_confirmation_data import AddressCoinsTransactionConfirmedEachConfirmationData
from cryptoapis.model.address_coins_transaction_confirmed_each_confirmation_data_item import AddressCoinsTransactionConfirmedEachConfirmationDataItem
from cryptoapis.model.address_coins_transaction_confirmed_each_confirmation_data_item_mined_in_block import AddressCoinsTransactionConfirmedEachConfirmationDataItemMinedInBlock
from cryptoapis.model.address_coins_transaction_unconfirmed import AddressCoinsTransactionUnconfirmed
from cryptoapis.model.address_coins_transaction_unconfirmed_data import AddressCoinsTransactionUnconfirmedData
from cryptoapis.model.address_coins_transaction_unconfirmed_data_item import AddressCoinsTransactionUnconfirmedDataItem
from cryptoapis.model.address_tokens_transaction_confirmed import AddressTokensTransactionConfirmed
from cryptoapis.model.address_tokens_transaction_confirmed_data import AddressTokensTransactionConfirmedData
from cryptoapis.model.address_tokens_transaction_confirmed_data_item import AddressTokensTransactionConfirmedDataItem
from cryptoapis.model.address_tokens_transaction_confirmed_data_item_mined_in_block import AddressTokensTransactionConfirmedDataItemMinedInBlock
from cryptoapis.model.address_tokens_transaction_confirmed_each_confirmation import AddressTokensTransactionConfirmedEachConfirmation
from cryptoapis.model.address_tokens_transaction_confirmed_each_confirmation_data import AddressTokensTransactionConfirmedEachConfirmationData
from cryptoapis.model.address_tokens_transaction_confirmed_each_confirmation_data_item import AddressTokensTransactionConfirmedEachConfirmationDataItem
from cryptoapis.model.address_tokens_transaction_confirmed_each_confirmation_data_item_mined_in_block import AddressTokensTransactionConfirmedEachConfirmationDataItemMinedInBlock
from cryptoapis.model.address_tokens_transaction_confirmed_each_confirmation_ethereumerc20token import AddressTokensTransactionConfirmedEachConfirmationEthereumerc20token
from cryptoapis.model.address_tokens_transaction_confirmed_each_confirmation_ethereumerc721token import AddressTokensTransactionConfirmedEachConfirmationEthereumerc721token
from cryptoapis.model.address_tokens_transaction_confirmed_each_confirmation_omnilayertoken import AddressTokensTransactionConfirmedEachConfirmationOmnilayertoken
from cryptoapis.model.address_tokens_transaction_confirmed_each_confirmation_token import AddressTokensTransactionConfirmedEachConfirmationToken
from cryptoapis.model.address_tokens_transaction_confirmed_ethereumerc20token import AddressTokensTransactionConfirmedEthereumerc20token
from cryptoapis.model.address_tokens_transaction_confirmed_ethereumerc721token import AddressTokensTransactionConfirmedEthereumerc721token
from cryptoapis.model.address_tokens_transaction_confirmed_omnilayertoken import AddressTokensTransactionConfirmedOmnilayertoken
from cryptoapis.model.address_tokens_transaction_confirmed_token import AddressTokensTransactionConfirmedToken
from cryptoapis.model.address_tokens_transaction_unconfirmed import AddressTokensTransactionUnconfirmed
from cryptoapis.model.address_tokens_transaction_unconfirmed_data import AddressTokensTransactionUnconfirmedData
from cryptoapis.model.address_tokens_transaction_unconfirmed_data_item import AddressTokensTransactionUnconfirmedDataItem
from cryptoapis.model.address_tokens_transaction_unconfirmed_ethereumerc20token import AddressTokensTransactionUnconfirmedEthereumerc20token
from cryptoapis.model.address_tokens_transaction_unconfirmed_ethereumerc721token import AddressTokensTransactionUnconfirmedEthereumerc721token
from cryptoapis.model.address_tokens_transaction_unconfirmed_omnilayertoken import AddressTokensTransactionUnconfirmedOmnilayertoken
from cryptoapis.model.address_tokens_transaction_unconfirmed_token import AddressTokensTransactionUnconfirmedToken
from cryptoapis.model.already_exists import AlreadyExists
from cryptoapis.model.already_exists_error import AlreadyExistsError
from cryptoapis.model.banned_ip_address import BannedIpAddress
from cryptoapis.model.banned_ip_address_error import BannedIpAddressError
from cryptoapis.model.banned_ip_address_error_details import BannedIpAddressErrorDetails
from cryptoapis.model.block_mined import BlockMined
from cryptoapis.model.block_mined_data import BlockMinedData
from cryptoapis.model.block_mined_data_item import BlockMinedDataItem
from cryptoapis.model.blockchain_data_block_not_found import BlockchainDataBlockNotFound
from cryptoapis.model.blockchain_data_block_not_found_error import BlockchainDataBlockNotFoundError
from cryptoapis.model.blockchain_data_internal_transaction_not_found import BlockchainDataInternalTransactionNotFound
from cryptoapis.model.blockchain_data_internal_transaction_not_found_error import BlockchainDataInternalTransactionNotFoundError
from cryptoapis.model.blockchain_data_transaction_not_found import BlockchainDataTransactionNotFound
from cryptoapis.model.blockchain_data_transaction_not_found_error import BlockchainDataTransactionNotFoundError
from cryptoapis.model.blockchain_events_callbacks_limit_reached import BlockchainEventsCallbacksLimitReached
from cryptoapis.model.blockchain_events_callbacks_limit_reached_error import BlockchainEventsCallbacksLimitReachedError
from cryptoapis.model.coins_forwarding_automations_limit_reached import CoinsForwardingAutomationsLimitReached
from cryptoapis.model.coins_forwarding_automations_limit_reached_error import CoinsForwardingAutomationsLimitReachedError
from cryptoapis.model.coins_forwarding_fail import CoinsForwardingFail
from cryptoapis.model.coins_forwarding_fail_data import CoinsForwardingFailData
from cryptoapis.model.coins_forwarding_fail_data_item import CoinsForwardingFailDataItem
from cryptoapis.model.coins_forwarding_success import CoinsForwardingSuccess
from cryptoapis.model.coins_forwarding_success_data import CoinsForwardingSuccessData
from cryptoapis.model.coins_forwarding_success_data_item import CoinsForwardingSuccessDataItem
from cryptoapis.model.could_not_calculate_rate_for_pair import CouldNotCalculateRateForPair
from cryptoapis.model.could_not_calculate_rate_for_pair_error import CouldNotCalculateRateForPairError
from cryptoapis.model.create_automatic_coins_forwarding_r import CreateAutomaticCoinsForwardingR
from cryptoapis.model.create_automatic_coins_forwarding_rb import CreateAutomaticCoinsForwardingRB
from cryptoapis.model.create_automatic_coins_forwarding_rb_data import CreateAutomaticCoinsForwardingRBData
from cryptoapis.model.create_automatic_coins_forwarding_rb_data_item import CreateAutomaticCoinsForwardingRBDataItem
from cryptoapis.model.create_automatic_coins_forwarding_r_data import CreateAutomaticCoinsForwardingRData
from cryptoapis.model.create_automatic_coins_forwarding_ri import CreateAutomaticCoinsForwardingRI
from cryptoapis.model.create_automatic_tokens_forwarding_r import CreateAutomaticTokensForwardingR
from cryptoapis.model.create_automatic_tokens_forwarding_rb import CreateAutomaticTokensForwardingRB
from cryptoapis.model.create_automatic_tokens_forwarding_rb_data import CreateAutomaticTokensForwardingRBData
from cryptoapis.model.create_automatic_tokens_forwarding_rb_data_item import CreateAutomaticTokensForwardingRBDataItem
from cryptoapis.model.create_automatic_tokens_forwarding_rb_token_data import CreateAutomaticTokensForwardingRBTokenData
from cryptoapis.model.create_automatic_tokens_forwarding_rb_token_data_bitcoin_omni_token import CreateAutomaticTokensForwardingRBTokenDataBitcoinOmniToken
from cryptoapis.model.create_automatic_tokens_forwarding_rb_token_data_ethereum_token import CreateAutomaticTokensForwardingRBTokenDataEthereumToken
from cryptoapis.model.create_automatic_tokens_forwarding_r_data import CreateAutomaticTokensForwardingRData
from cryptoapis.model.create_automatic_tokens_forwarding_ri import CreateAutomaticTokensForwardingRI
from cryptoapis.model.create_automatic_tokens_forwarding_rits import CreateAutomaticTokensForwardingRITS
from cryptoapis.model.create_automatic_tokens_forwarding_ritsbot import CreateAutomaticTokensForwardingRITSBOT
from cryptoapis.model.create_automatic_tokens_forwarding_ritset import CreateAutomaticTokensForwardingRITSET
from cryptoapis.model.create_coins_transaction_request_from_address_r import CreateCoinsTransactionRequestFromAddressR
from cryptoapis.model.create_coins_transaction_request_from_address_rb import CreateCoinsTransactionRequestFromAddressRB
from cryptoapis.model.create_coins_transaction_request_from_address_rb_data import CreateCoinsTransactionRequestFromAddressRBData
from cryptoapis.model.create_coins_transaction_request_from_address_rb_data_item import CreateCoinsTransactionRequestFromAddressRBDataItem
from cryptoapis.model.create_coins_transaction_request_from_address_r_data import CreateCoinsTransactionRequestFromAddressRData
from cryptoapis.model.create_coins_transaction_request_from_address_ri import CreateCoinsTransactionRequestFromAddressRI
from cryptoapis.model.create_coins_transaction_request_from_address_ri_recipients import CreateCoinsTransactionRequestFromAddressRIRecipients
from cryptoapis.model.create_coins_transaction_request_from_address_ri_senders import CreateCoinsTransactionRequestFromAddressRISenders
from cryptoapis.model.create_coins_transaction_request_from_wallet_r import CreateCoinsTransactionRequestFromWalletR
from cryptoapis.model.create_coins_transaction_request_from_wallet_rb import CreateCoinsTransactionRequestFromWalletRB
from cryptoapis.model.create_coins_transaction_request_from_wallet_rb_data import CreateCoinsTransactionRequestFromWalletRBData
from cryptoapis.model.create_coins_transaction_request_from_wallet_rb_data_item import CreateCoinsTransactionRequestFromWalletRBDataItem
from cryptoapis.model.create_coins_transaction_request_from_wallet_rb_data_item_destinations import CreateCoinsTransactionRequestFromWalletRBDataItemDestinations
from cryptoapis.model.create_coins_transaction_request_from_wallet_r_data import CreateCoinsTransactionRequestFromWalletRData
from cryptoapis.model.create_coins_transaction_request_from_wallet_ri import CreateCoinsTransactionRequestFromWalletRI
from cryptoapis.model.create_coins_transaction_request_from_wallet_ri_recipients import CreateCoinsTransactionRequestFromWalletRIRecipients
from cryptoapis.model.create_tokens_transaction_request_from_address_r import CreateTokensTransactionRequestFromAddressR
from cryptoapis.model.create_tokens_transaction_request_from_address_rb import CreateTokensTransactionRequestFromAddressRB
from cryptoapis.model.create_tokens_transaction_request_from_address_rb_data import CreateTokensTransactionRequestFromAddressRBData
from cryptoapis.model.create_tokens_transaction_request_from_address_rb_data_item import CreateTokensTransactionRequestFromAddressRBDataItem
from cryptoapis.model.create_tokens_transaction_request_from_address_r_data import CreateTokensTransactionRequestFromAddressRData
from cryptoapis.model.create_tokens_transaction_request_from_address_ri import CreateTokensTransactionRequestFromAddressRI
from cryptoapis.model.create_tokens_transaction_request_from_address_ri_recipients import CreateTokensTransactionRequestFromAddressRIRecipients
from cryptoapis.model.create_tokens_transaction_request_from_address_ri_senders import CreateTokensTransactionRequestFromAddressRISenders
from cryptoapis.model.create_tokens_transaction_request_from_address_ri_token_type_specific_data import CreateTokensTransactionRequestFromAddressRITokenTypeSpecificData
from cryptoapis.model.create_tokens_transaction_request_from_address_ri_token_type_specific_data_bitcoin_omni_token import CreateTokensTransactionRequestFromAddressRITokenTypeSpecificDataBitcoinOmniToken
from cryptoapis.model.create_tokens_transaction_request_from_address_ri_token_type_specific_data_ethereum_erc20_token import CreateTokensTransactionRequestFromAddressRITokenTypeSpecificDataEthereumErc20Token
from cryptoapis.model.delete_automatic_coins_forwarding_r import DeleteAutomaticCoinsForwardingR
from cryptoapis.model.delete_automatic_coins_forwarding_r_data import DeleteAutomaticCoinsForwardingRData
from cryptoapis.model.delete_automatic_coins_forwarding_ri import DeleteAutomaticCoinsForwardingRI
from cryptoapis.model.delete_automatic_tokens_forwarding_r import DeleteAutomaticTokensForwardingR
from cryptoapis.model.delete_automatic_tokens_forwarding_r_data import DeleteAutomaticTokensForwardingRData
from cryptoapis.model.delete_automatic_tokens_forwarding_ri import DeleteAutomaticTokensForwardingRI
from cryptoapis.model.delete_automatic_tokens_forwarding_rits import DeleteAutomaticTokensForwardingRITS
from cryptoapis.model.delete_automatic_tokens_forwarding_ritsbot import DeleteAutomaticTokensForwardingRITSBOT
from cryptoapis.model.delete_automatic_tokens_forwarding_ritset import DeleteAutomaticTokensForwardingRITSET
from cryptoapis.model.delete_blockchain_event_subscription_r import DeleteBlockchainEventSubscriptionR
from cryptoapis.model.delete_blockchain_event_subscription_r_data import DeleteBlockchainEventSubscriptionRData
from cryptoapis.model.delete_blockchain_event_subscription_ri import DeleteBlockchainEventSubscriptionRI
from cryptoapis.model.endpoint_not_allowed_for_api_key import EndpointNotAllowedForApiKey
from cryptoapis.model.endpoint_not_allowed_for_api_key_error import EndpointNotAllowedForApiKeyError
from cryptoapis.model.endpoint_not_allowed_for_plan import EndpointNotAllowedForPlan
from cryptoapis.model.endpoint_not_allowed_for_plan_error import EndpointNotAllowedForPlanError
from cryptoapis.model.feature_mainnets_not_allowed_for_plan import FeatureMainnetsNotAllowedForPlan
from cryptoapis.model.feature_mainnets_not_allowed_for_plan_error import FeatureMainnetsNotAllowedForPlanError
from cryptoapis.model.generate_receiving_address_r import GenerateReceivingAddressR
from cryptoapis.model.generate_receiving_address_rb import GenerateReceivingAddressRB
from cryptoapis.model.generate_receiving_address_rb_data import GenerateReceivingAddressRBData
from cryptoapis.model.generate_receiving_address_rb_data_item import GenerateReceivingAddressRBDataItem
from cryptoapis.model.generate_receiving_address_r_data import GenerateReceivingAddressRData
from cryptoapis.model.generate_receiving_address_ri import GenerateReceivingAddressRI
from cryptoapis.model.get_address_details_r import GetAddressDetailsR
from cryptoapis.model.get_address_details_r_data import GetAddressDetailsRData
from cryptoapis.model.get_address_details_ri import GetAddressDetailsRI
from cryptoapis.model.get_address_details_ri_confirmed_balance import GetAddressDetailsRIConfirmedBalance
from cryptoapis.model.get_address_details_ri_total_received import GetAddressDetailsRITotalReceived
from cryptoapis.model.get_address_details_ri_total_spent import GetAddressDetailsRITotalSpent
from cryptoapis.model.get_block_details_by_block_hash_r import GetBlockDetailsByBlockHashR
from cryptoapis.model.get_block_details_by_block_hash_r_data import GetBlockDetailsByBlockHashRData
from cryptoapis.model.get_block_details_by_block_hash_ri import GetBlockDetailsByBlockHashRI
from cryptoapis.model.get_block_details_by_block_hash_ribs import GetBlockDetailsByBlockHashRIBS
from cryptoapis.model.get_block_details_by_block_hash_ribsb import GetBlockDetailsByBlockHashRIBSB
from cryptoapis.model.get_block_details_by_block_hash_ribsbc import GetBlockDetailsByBlockHashRIBSBC
from cryptoapis.model.get_block_details_by_block_hash_ribsd import GetBlockDetailsByBlockHashRIBSD
from cryptoapis.model.get_block_details_by_block_hash_ribsd2 import GetBlockDetailsByBlockHashRIBSD2
from cryptoapis.model.get_block_details_by_block_hash_ribse import GetBlockDetailsByBlockHashRIBSE
from cryptoapis.model.get_block_details_by_block_hash_ribsec import GetBlockDetailsByBlockHashRIBSEC
from cryptoapis.model.get_block_details_by_block_hash_ribsl import GetBlockDetailsByBlockHashRIBSL
from cryptoapis.model.get_block_details_by_block_height_r import GetBlockDetailsByBlockHeightR
from cryptoapis.model.get_block_details_by_block_height_r_data import GetBlockDetailsByBlockHeightRData
from cryptoapis.model.get_block_details_by_block_height_ri import GetBlockDetailsByBlockHeightRI
from cryptoapis.model.get_block_details_by_block_height_ribs import GetBlockDetailsByBlockHeightRIBS
from cryptoapis.model.get_block_details_by_block_height_ribsb import GetBlockDetailsByBlockHeightRIBSB
from cryptoapis.model.get_block_details_by_block_height_ribsbc import GetBlockDetailsByBlockHeightRIBSBC
from cryptoapis.model.get_block_details_by_block_height_ribsd import GetBlockDetailsByBlockHeightRIBSD
from cryptoapis.model.get_block_details_by_block_height_ribsd2 import GetBlockDetailsByBlockHeightRIBSD2
from cryptoapis.model.get_block_details_by_block_height_ribse import GetBlockDetailsByBlockHeightRIBSE
from cryptoapis.model.get_block_details_by_block_height_ribsec import GetBlockDetailsByBlockHeightRIBSEC
from cryptoapis.model.get_block_details_by_block_height_ribsl import GetBlockDetailsByBlockHeightRIBSL
from cryptoapis.model.get_contract_details_by_address_r import GetContractDetailsByAddressR
from cryptoapis.model.get_contract_details_by_address_r_data import GetContractDetailsByAddressRData
from cryptoapis.model.get_contract_details_by_address_ri import GetContractDetailsByAddressRI
from cryptoapis.model.get_exchange_rate_by_asset_symbols_r import GetExchangeRateByAssetSymbolsR
from cryptoapis.model.get_exchange_rate_by_asset_symbols_r_data import GetExchangeRateByAssetSymbolsRData
from cryptoapis.model.get_exchange_rate_by_asset_symbols_ri import GetExchangeRateByAssetSymbolsRI
from cryptoapis.model.get_exchange_rate_by_assets_ids_r import GetExchangeRateByAssetsIDsR
from cryptoapis.model.get_exchange_rate_by_assets_ids_r_data import GetExchangeRateByAssetsIDsRData
from cryptoapis.model.get_exchange_rate_by_assets_ids_ri import GetExchangeRateByAssetsIDsRI
from cryptoapis.model.get_fee_address_details_r import GetFeeAddressDetailsR
from cryptoapis.model.get_fee_address_details_r_data import GetFeeAddressDetailsRData
from cryptoapis.model.get_fee_address_details_ri import GetFeeAddressDetailsRI
from cryptoapis.model.get_fee_address_details_ri_balance import GetFeeAddressDetailsRIBalance
from cryptoapis.model.get_fee_recommendations_r import GetFeeRecommendationsR
from cryptoapis.model.get_fee_recommendations_r_data import GetFeeRecommendationsRData
from cryptoapis.model.get_fee_recommendations_ri import GetFeeRecommendationsRI
from cryptoapis.model.get_hd_wallet_x_pub_y_pub_z_pub_details_r import GetHDWalletXPubYPubZPubDetailsR
from cryptoapis.model.get_hd_wallet_x_pub_y_pub_z_pub_details_r_data import GetHDWalletXPubYPubZPubDetailsRData
from cryptoapis.model.get_hd_wallet_x_pub_y_pub_z_pub_details_ri import GetHDWalletXPubYPubZPubDetailsRI
from cryptoapis.model.get_internal_transaction_by_transaction_hash_and_operation_id_r import GetInternalTransactionByTransactionHashAndOperationIdR
from cryptoapis.model.get_internal_transaction_by_transaction_hash_and_operation_id_r_data import GetInternalTransactionByTransactionHashAndOperationIdRData
from cryptoapis.model.get_internal_transaction_by_transaction_hash_and_operation_id_ri import GetInternalTransactionByTransactionHashAndOperationIdRI
from cryptoapis.model.get_latest_mined_block_r import GetLatestMinedBlockR
from cryptoapis.model.get_latest_mined_block_r_data import GetLatestMinedBlockRData
from cryptoapis.model.get_latest_mined_block_ri import GetLatestMinedBlockRI
from cryptoapis.model.get_latest_mined_block_ribs import GetLatestMinedBlockRIBS
from cryptoapis.model.get_latest_mined_block_ribsb import GetLatestMinedBlockRIBSB
from cryptoapis.model.get_latest_mined_block_ribsbc import GetLatestMinedBlockRIBSBC
from cryptoapis.model.get_latest_mined_block_ribsd import GetLatestMinedBlockRIBSD
from cryptoapis.model.get_latest_mined_block_ribsd2 import GetLatestMinedBlockRIBSD2
from cryptoapis.model.get_latest_mined_block_ribse import GetLatestMinedBlockRIBSE
from cryptoapis.model.get_latest_mined_block_ribsec import GetLatestMinedBlockRIBSEC
from cryptoapis.model.get_latest_mined_block_ribsl import GetLatestMinedBlockRIBSL
from cryptoapis.model.get_latest_mined_xrp_ripple_block_r import GetLatestMinedXRPRippleBlockR
from cryptoapis.model.get_latest_mined_xrp_ripple_block_r_data import GetLatestMinedXRPRippleBlockRData
from cryptoapis.model.get_latest_mined_xrp_ripple_block_ri import GetLatestMinedXRPRippleBlockRI
from cryptoapis.model.get_latest_mined_xrp_ripple_block_ri_total_coins import GetLatestMinedXRPRippleBlockRITotalCoins
from cryptoapis.model.get_latest_mined_xrp_ripple_block_ri_total_fees import GetLatestMinedXRPRippleBlockRITotalFees
from cryptoapis.model.get_latest_mined_zilliqa_block_r import GetLatestMinedZilliqaBlockR
from cryptoapis.model.get_latest_mined_zilliqa_block_r_data import GetLatestMinedZilliqaBlockRData
from cryptoapis.model.get_latest_mined_zilliqa_block_ri import GetLatestMinedZilliqaBlockRI
from cryptoapis.model.get_omni_transaction_details_by_transaction_id_txid_r import GetOmniTransactionDetailsByTransactionIDTxidR
from cryptoapis.model.get_omni_transaction_details_by_transaction_id_txid_r_data import GetOmniTransactionDetailsByTransactionIDTxidRData
from cryptoapis.model.get_omni_transaction_details_by_transaction_id_txid_ri import GetOmniTransactionDetailsByTransactionIDTxidRI
from cryptoapis.model.get_omni_transaction_details_by_transaction_id_txid_ri_senders import GetOmniTransactionDetailsByTransactionIDTxidRISenders
from cryptoapis.model.get_transaction_details_by_transaction_idr import GetTransactionDetailsByTransactionIDR
from cryptoapis.model.get_transaction_details_by_transaction_idr_data import GetTransactionDetailsByTransactionIDRData
from cryptoapis.model.get_transaction_details_by_transaction_idri import GetTransactionDetailsByTransactionIDRI
from cryptoapis.model.get_transaction_details_by_transaction_idribs import GetTransactionDetailsByTransactionIDRIBS
from cryptoapis.model.get_transaction_details_by_transaction_idribsb import GetTransactionDetailsByTransactionIDRIBSB
from cryptoapis.model.get_transaction_details_by_transaction_idribsbc import GetTransactionDetailsByTransactionIDRIBSBC
from cryptoapis.model.get_transaction_details_by_transaction_idribsbc_script_pub_key import GetTransactionDetailsByTransactionIDRIBSBCScriptPubKey
from cryptoapis.model.get_transaction_details_by_transaction_idribsbc_vin import GetTransactionDetailsByTransactionIDRIBSBCVin
from cryptoapis.model.get_transaction_details_by_transaction_idribsbc_vout import GetTransactionDetailsByTransactionIDRIBSBCVout
from cryptoapis.model.get_transaction_details_by_transaction_idribsb_script_pub_key import GetTransactionDetailsByTransactionIDRIBSBScriptPubKey
from cryptoapis.model.get_transaction_details_by_transaction_idribsb_script_sig import GetTransactionDetailsByTransactionIDRIBSBScriptSig
from cryptoapis.model.get_transaction_details_by_transaction_idribsb_vin import GetTransactionDetailsByTransactionIDRIBSBVin
from cryptoapis.model.get_transaction_details_by_transaction_idribsb_vout import GetTransactionDetailsByTransactionIDRIBSBVout
from cryptoapis.model.get_transaction_details_by_transaction_idribsd import GetTransactionDetailsByTransactionIDRIBSD
from cryptoapis.model.get_transaction_details_by_transaction_idribsd2 import GetTransactionDetailsByTransactionIDRIBSD2
from cryptoapis.model.get_transaction_details_by_transaction_idribsd2_script_pub_key import GetTransactionDetailsByTransactionIDRIBSD2ScriptPubKey
from cryptoapis.model.get_transaction_details_by_transaction_idribsd2_script_sig import GetTransactionDetailsByTransactionIDRIBSD2ScriptSig
from cryptoapis.model.get_transaction_details_by_transaction_idribsd2_vin import GetTransactionDetailsByTransactionIDRIBSD2Vin
from cryptoapis.model.get_transaction_details_by_transaction_idribsd2_vout import GetTransactionDetailsByTransactionIDRIBSD2Vout
from cryptoapis.model.get_transaction_details_by_transaction_idribsd_script_pub_key import GetTransactionDetailsByTransactionIDRIBSDScriptPubKey
from cryptoapis.model.get_transaction_details_by_transaction_idribsd_script_sig import GetTransactionDetailsByTransactionIDRIBSDScriptSig
from cryptoapis.model.get_transaction_details_by_transaction_idribsd_vin import GetTransactionDetailsByTransactionIDRIBSDVin
from cryptoapis.model.get_transaction_details_by_transaction_idribsd_vout import GetTransactionDetailsByTransactionIDRIBSDVout
from cryptoapis.model.get_transaction_details_by_transaction_idribse import GetTransactionDetailsByTransactionIDRIBSE
from cryptoapis.model.get_transaction_details_by_transaction_idribsec import GetTransactionDetailsByTransactionIDRIBSEC
from cryptoapis.model.get_transaction_details_by_transaction_idribsec_gas_price import GetTransactionDetailsByTransactionIDRIBSECGasPrice
from cryptoapis.model.get_transaction_details_by_transaction_idribse_gas_price import GetTransactionDetailsByTransactionIDRIBSEGasPrice
from cryptoapis.model.get_transaction_details_by_transaction_idribsl import GetTransactionDetailsByTransactionIDRIBSL
from cryptoapis.model.get_transaction_details_by_transaction_idribsl_script_pub_key import GetTransactionDetailsByTransactionIDRIBSLScriptPubKey
from cryptoapis.model.get_transaction_details_by_transaction_idribsl_script_sig import GetTransactionDetailsByTransactionIDRIBSLScriptSig
from cryptoapis.model.get_transaction_details_by_transaction_idribsl_vin import GetTransactionDetailsByTransactionIDRIBSLVin
from cryptoapis.model.get_transaction_details_by_transaction_idribsl_vout import GetTransactionDetailsByTransactionIDRIBSLVout
from cryptoapis.model.get_transaction_details_by_transaction_idri_fee import GetTransactionDetailsByTransactionIDRIFee
from cryptoapis.model.get_transaction_details_by_transaction_idri_recipients import GetTransactionDetailsByTransactionIDRIRecipients
from cryptoapis.model.get_transaction_details_by_transaction_idri_senders import GetTransactionDetailsByTransactionIDRISenders
from cryptoapis.model.get_unconfirmed_omni_transaction_by_transaction_id_txid_r import GetUnconfirmedOmniTransactionByTransactionIDTxidR
from cryptoapis.model.get_unconfirmed_omni_transaction_by_transaction_id_txid_r_data import GetUnconfirmedOmniTransactionByTransactionIDTxidRData
from cryptoapis.model.get_unconfirmed_omni_transaction_by_transaction_id_txid_ri import GetUnconfirmedOmniTransactionByTransactionIDTxidRI
from cryptoapis.model.get_unconfirmed_omni_transaction_by_transaction_id_txid_ri_recipients import GetUnconfirmedOmniTransactionByTransactionIDTxidRIRecipients
from cryptoapis.model.get_unconfirmed_omni_transaction_by_transaction_id_txid_ri_senders import GetUnconfirmedOmniTransactionByTransactionIDTxidRISenders
from cryptoapis.model.get_wallet_asset_details_r import GetWalletAssetDetailsR
from cryptoapis.model.get_wallet_asset_details_r_data import GetWalletAssetDetailsRData
from cryptoapis.model.get_wallet_asset_details_ri import GetWalletAssetDetailsRI
from cryptoapis.model.get_wallet_asset_details_ri_confirmed_balance import GetWalletAssetDetailsRIConfirmedBalance
from cryptoapis.model.get_wallet_asset_details_ri_recieved_confirmed_amount import GetWalletAssetDetailsRIRecievedConfirmedAmount
from cryptoapis.model.get_wallet_asset_details_ri_sent_confirmed_amount import GetWalletAssetDetailsRISentConfirmedAmount
from cryptoapis.model.get_xrp_ripple_address_details_r import GetXRPRippleAddressDetailsR
from cryptoapis.model.get_xrp_ripple_address_details_r_data import GetXRPRippleAddressDetailsRData
from cryptoapis.model.get_xrp_ripple_address_details_ri import GetXRPRippleAddressDetailsRI
from cryptoapis.model.get_xrp_ripple_address_details_ri_balance import GetXRPRippleAddressDetailsRIBalance
from cryptoapis.model.get_xrp_ripple_block_details_by_block_hash_r import GetXRPRippleBlockDetailsByBlockHashR
from cryptoapis.model.get_xrp_ripple_block_details_by_block_hash_r_data import GetXRPRippleBlockDetailsByBlockHashRData
from cryptoapis.model.get_xrp_ripple_block_details_by_block_hash_ri import GetXRPRippleBlockDetailsByBlockHashRI
from cryptoapis.model.get_xrp_ripple_block_details_by_block_hash_ri_total_coins import GetXRPRippleBlockDetailsByBlockHashRITotalCoins
from cryptoapis.model.get_xrp_ripple_block_details_by_block_height_r import GetXRPRippleBlockDetailsByBlockHeightR
from cryptoapis.model.get_xrp_ripple_block_details_by_block_height_r_data import GetXRPRippleBlockDetailsByBlockHeightRData
from cryptoapis.model.get_xrp_ripple_block_details_by_block_height_ri import GetXRPRippleBlockDetailsByBlockHeightRI
from cryptoapis.model.get_xrp_ripple_block_details_by_block_height_ri_total_coins import GetXRPRippleBlockDetailsByBlockHeightRITotalCoins
from cryptoapis.model.get_xrp_ripple_block_details_by_block_height_ri_total_fees import GetXRPRippleBlockDetailsByBlockHeightRITotalFees
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idr import GetXRPRippleTransactionDetailsByTransactionIDR
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idr_data import GetXRPRippleTransactionDetailsByTransactionIDRData
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri import GetXRPRippleTransactionDetailsByTransactionIDRI
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_fee import GetXRPRippleTransactionDetailsByTransactionIDRIFee
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_offer import GetXRPRippleTransactionDetailsByTransactionIDRIOffer
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_receive import GetXRPRippleTransactionDetailsByTransactionIDRIReceive
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_recipients import GetXRPRippleTransactionDetailsByTransactionIDRIRecipients
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_senders import GetXRPRippleTransactionDetailsByTransactionIDRISenders
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_value import GetXRPRippleTransactionDetailsByTransactionIDRIValue
from cryptoapis.model.get_zilliqa_address_details_r import GetZilliqaAddressDetailsR
from cryptoapis.model.get_zilliqa_address_details_r_data import GetZilliqaAddressDetailsRData
from cryptoapis.model.get_zilliqa_address_details_ri import GetZilliqaAddressDetailsRI
from cryptoapis.model.get_zilliqa_address_details_ri_balance import GetZilliqaAddressDetailsRIBalance
from cryptoapis.model.get_zilliqa_block_details_by_block_hash_r import GetZilliqaBlockDetailsByBlockHashR
from cryptoapis.model.get_zilliqa_block_details_by_block_hash_r_data import GetZilliqaBlockDetailsByBlockHashRData
from cryptoapis.model.get_zilliqa_block_details_by_block_hash_ri import GetZilliqaBlockDetailsByBlockHashRI
from cryptoapis.model.get_zilliqa_block_details_by_block_height_r import GetZilliqaBlockDetailsByBlockHeightR
from cryptoapis.model.get_zilliqa_block_details_by_block_height_r_data import GetZilliqaBlockDetailsByBlockHeightRData
from cryptoapis.model.get_zilliqa_block_details_by_block_height_ri import GetZilliqaBlockDetailsByBlockHeightRI
from cryptoapis.model.get_zilliqa_transaction_details_by_transaction_idr import GetZilliqaTransactionDetailsByTransactionIDR
from cryptoapis.model.get_zilliqa_transaction_details_by_transaction_idr_data import GetZilliqaTransactionDetailsByTransactionIDRData
from cryptoapis.model.get_zilliqa_transaction_details_by_transaction_idri import GetZilliqaTransactionDetailsByTransactionIDRI
from cryptoapis.model.get_zilliqa_transaction_details_by_transaction_idri_fee import GetZilliqaTransactionDetailsByTransactionIDRIFee
from cryptoapis.model.get_zilliqa_transaction_details_by_transaction_idri_recipients import GetZilliqaTransactionDetailsByTransactionIDRIRecipients
from cryptoapis.model.get_zilliqa_transaction_details_by_transaction_idri_senders import GetZilliqaTransactionDetailsByTransactionIDRISenders
from cryptoapis.model.insufficient_credits import InsufficientCredits
from cryptoapis.model.insufficient_credits_error import InsufficientCreditsError
from cryptoapis.model.invalid_api_key import InvalidApiKey
from cryptoapis.model.invalid_api_key_error import InvalidApiKeyError
from cryptoapis.model.invalid_blockchain import InvalidBlockchain
from cryptoapis.model.invalid_blockchain_error import InvalidBlockchainError
from cryptoapis.model.invalid_data import InvalidData
from cryptoapis.model.invalid_data_error import InvalidDataError
from cryptoapis.model.invalid_network import InvalidNetwork
from cryptoapis.model.invalid_network_error import InvalidNetworkError
from cryptoapis.model.invalid_pagination import InvalidPagination
from cryptoapis.model.invalid_pagination_error import InvalidPaginationError
from cryptoapis.model.invalid_request_body_structure import InvalidRequestBodyStructure
from cryptoapis.model.invalid_request_body_structure_error import InvalidRequestBodyStructureError
from cryptoapis.model.invalid_xpub import InvalidXpub
from cryptoapis.model.invalid_xpub_error import InvalidXpubError
from cryptoapis.model.limit_greater_than_allowed import LimitGreaterThanAllowed
from cryptoapis.model.limit_greater_than_allowed_error import LimitGreaterThanAllowedError
from cryptoapis.model.list_assets_details_r import ListAssetsDetailsR
from cryptoapis.model.list_assets_details_r_data import ListAssetsDetailsRData
from cryptoapis.model.list_assets_details_ri import ListAssetsDetailsRI
from cryptoapis.model.list_assets_details_ri_asset_logo import ListAssetsDetailsRIAssetLogo
from cryptoapis.model.list_assets_details_ri_latest_rate import ListAssetsDetailsRILatestRate
from cryptoapis.model.list_assets_details_ri_specific_data import ListAssetsDetailsRISpecificData
from cryptoapis.model.list_assets_details_ri_specific_data_crypto_type_data import ListAssetsDetailsRISpecificDataCryptoTypeData
from cryptoapis.model.list_blockchain_events_subscriptions_r import ListBlockchainEventsSubscriptionsR
from cryptoapis.model.list_blockchain_events_subscriptions_r_data import ListBlockchainEventsSubscriptionsRData
from cryptoapis.model.list_blockchain_events_subscriptions_ri import ListBlockchainEventsSubscriptionsRI
from cryptoapis.model.list_coins_forwarding_automations_r import ListCoinsForwardingAutomationsR
from cryptoapis.model.list_coins_forwarding_automations_r_data import ListCoinsForwardingAutomationsRData
from cryptoapis.model.list_coins_forwarding_automations_ri import ListCoinsForwardingAutomationsRI
from cryptoapis.model.list_hd_wallet_x_pub_y_pub_z_pub_transactions_r import ListHDWalletXPubYPubZPubTransactionsR
from cryptoapis.model.list_hd_wallet_x_pub_y_pub_z_pub_transactions_r_data import ListHDWalletXPubYPubZPubTransactionsRData
from cryptoapis.model.list_hd_wallet_x_pub_y_pub_z_pub_transactions_ri import ListHDWalletXPubYPubZPubTransactionsRI
from cryptoapis.model.list_hd_wallet_x_pub_y_pub_z_pub_transactions_ri_fee import ListHDWalletXPubYPubZPubTransactionsRIFee
from cryptoapis.model.list_hd_wallet_x_pub_y_pub_z_pub_transactions_ri_recipients import ListHDWalletXPubYPubZPubTransactionsRIRecipients
from cryptoapis.model.list_hd_wallet_x_pub_y_pub_z_pub_transactions_ri_senders import ListHDWalletXPubYPubZPubTransactionsRISenders
from cryptoapis.model.list_internal_transaction_details_by_transaction_hash_r import ListInternalTransactionDetailsByTransactionHashR
from cryptoapis.model.list_internal_transaction_details_by_transaction_hash_r_data import ListInternalTransactionDetailsByTransactionHashRData
from cryptoapis.model.list_internal_transaction_details_by_transaction_hash_ri import ListInternalTransactionDetailsByTransactionHashRI
from cryptoapis.model.list_omni_tokens_by_address_r import ListOmniTokensByAddressR
from cryptoapis.model.list_omni_tokens_by_address_r_data import ListOmniTokensByAddressRData
from cryptoapis.model.list_omni_tokens_by_address_ri import ListOmniTokensByAddressRI
from cryptoapis.model.list_omni_transactions_by_address_r import ListOmniTransactionsByAddressR
from cryptoapis.model.list_omni_transactions_by_address_r_data import ListOmniTransactionsByAddressRData
from cryptoapis.model.list_omni_transactions_by_address_ri import ListOmniTransactionsByAddressRI
from cryptoapis.model.list_omni_transactions_by_address_ri_fee import ListOmniTransactionsByAddressRIFee
from cryptoapis.model.list_omni_transactions_by_address_ri_recipients import ListOmniTransactionsByAddressRIRecipients
from cryptoapis.model.list_omni_transactions_by_address_ri_senders import ListOmniTransactionsByAddressRISenders
from cryptoapis.model.list_omni_transactions_by_block_hash_r import ListOmniTransactionsByBlockHashR
from cryptoapis.model.list_omni_transactions_by_block_hash_r_data import ListOmniTransactionsByBlockHashRData
from cryptoapis.model.list_omni_transactions_by_block_hash_ri import ListOmniTransactionsByBlockHashRI
from cryptoapis.model.list_omni_transactions_by_block_hash_ri_fee import ListOmniTransactionsByBlockHashRIFee
from cryptoapis.model.list_omni_transactions_by_block_height_r import ListOmniTransactionsByBlockHeightR
from cryptoapis.model.list_omni_transactions_by_block_height_r_data import ListOmniTransactionsByBlockHeightRData
from cryptoapis.model.list_omni_transactions_by_block_height_ri import ListOmniTransactionsByBlockHeightRI
from cryptoapis.model.list_omni_transactions_by_block_height_ri_fee import ListOmniTransactionsByBlockHeightRIFee
from cryptoapis.model.list_omni_transactions_by_block_height_ri_recipients import ListOmniTransactionsByBlockHeightRIRecipients
from cryptoapis.model.list_omni_transactions_by_block_height_ri_senders import ListOmniTransactionsByBlockHeightRISenders
from cryptoapis.model.list_receiving_addresses_r import ListReceivingAddressesR
from cryptoapis.model.list_receiving_addresses_r_data import ListReceivingAddressesRData
from cryptoapis.model.list_receiving_addresses_ri import ListReceivingAddressesRI
from cryptoapis.model.list_supported_assets_r import ListSupportedAssetsR
from cryptoapis.model.list_supported_assets_r_data import ListSupportedAssetsRData
from cryptoapis.model.list_supported_assets_ri import ListSupportedAssetsRI
from cryptoapis.model.list_supported_tokens_r import ListSupportedTokensR
from cryptoapis.model.list_supported_tokens_r_data import ListSupportedTokensRData
from cryptoapis.model.list_supported_tokens_ri import ListSupportedTokensRI
from cryptoapis.model.list_tokens_by_address_r import ListTokensByAddressR
from cryptoapis.model.list_tokens_by_address_r_data import ListTokensByAddressRData
from cryptoapis.model.list_tokens_by_address_ri import ListTokensByAddressRI
from cryptoapis.model.list_tokens_forwarding_automations_r import ListTokensForwardingAutomationsR
from cryptoapis.model.list_tokens_forwarding_automations_r_data import ListTokensForwardingAutomationsRData
from cryptoapis.model.list_tokens_forwarding_automations_ri import ListTokensForwardingAutomationsRI
from cryptoapis.model.list_tokens_forwarding_automations_rits import ListTokensForwardingAutomationsRITS
from cryptoapis.model.list_tokens_forwarding_automations_ritsbot import ListTokensForwardingAutomationsRITSBOT
from cryptoapis.model.list_tokens_forwarding_automations_ritset import ListTokensForwardingAutomationsRITSET
from cryptoapis.model.list_tokens_transfers_by_address_r import ListTokensTransfersByAddressR
from cryptoapis.model.list_tokens_transfers_by_address_r_data import ListTokensTransfersByAddressRData
from cryptoapis.model.list_tokens_transfers_by_address_ri import ListTokensTransfersByAddressRI
from cryptoapis.model.list_tokens_transfers_by_transaction_hash_r import ListTokensTransfersByTransactionHashR
from cryptoapis.model.list_tokens_transfers_by_transaction_hash_r_data import ListTokensTransfersByTransactionHashRData
from cryptoapis.model.list_tokens_transfers_by_transaction_hash_ri import ListTokensTransfersByTransactionHashRI
from cryptoapis.model.list_transactions_by_address_r import ListTransactionsByAddressR
from cryptoapis.model.list_transactions_by_address_r_data import ListTransactionsByAddressRData
from cryptoapis.model.list_transactions_by_address_ri import ListTransactionsByAddressRI
from cryptoapis.model.list_transactions_by_address_ribs import ListTransactionsByAddressRIBS
from cryptoapis.model.list_transactions_by_address_ribsb import ListTransactionsByAddressRIBSB
from cryptoapis.model.list_transactions_by_address_ribsbc import ListTransactionsByAddressRIBSBC
from cryptoapis.model.list_transactions_by_address_ribsbc_vin import ListTransactionsByAddressRIBSBCVin
from cryptoapis.model.list_transactions_by_address_ribsb_script_pub_key import ListTransactionsByAddressRIBSBScriptPubKey
from cryptoapis.model.list_transactions_by_address_ribsb_vin import ListTransactionsByAddressRIBSBVin
from cryptoapis.model.list_transactions_by_address_ribsb_vout import ListTransactionsByAddressRIBSBVout
from cryptoapis.model.list_transactions_by_address_ribsd import ListTransactionsByAddressRIBSD
from cryptoapis.model.list_transactions_by_address_ribsd2 import ListTransactionsByAddressRIBSD2
from cryptoapis.model.list_transactions_by_address_ribsd2_script_pub_key import ListTransactionsByAddressRIBSD2ScriptPubKey
from cryptoapis.model.list_transactions_by_address_ribsd2_script_sig import ListTransactionsByAddressRIBSD2ScriptSig
from cryptoapis.model.list_transactions_by_address_ribsd2_vin import ListTransactionsByAddressRIBSD2Vin
from cryptoapis.model.list_transactions_by_address_ribsd2_vout import ListTransactionsByAddressRIBSD2Vout
from cryptoapis.model.list_transactions_by_address_ribsd_script_sig import ListTransactionsByAddressRIBSDScriptSig
from cryptoapis.model.list_transactions_by_address_ribsd_vin import ListTransactionsByAddressRIBSDVin
from cryptoapis.model.list_transactions_by_address_ribse import ListTransactionsByAddressRIBSE
from cryptoapis.model.list_transactions_by_address_ribsec import ListTransactionsByAddressRIBSEC
from cryptoapis.model.list_transactions_by_address_ribsec_gas_price import ListTransactionsByAddressRIBSECGasPrice
from cryptoapis.model.list_transactions_by_address_ribse_gas_price import ListTransactionsByAddressRIBSEGasPrice
from cryptoapis.model.list_transactions_by_address_ribsl import ListTransactionsByAddressRIBSL
from cryptoapis.model.list_transactions_by_address_ribsl_script_sig import ListTransactionsByAddressRIBSLScriptSig
from cryptoapis.model.list_transactions_by_address_ribsl_vin import ListTransactionsByAddressRIBSLVin
from cryptoapis.model.list_transactions_by_block_hash_r import ListTransactionsByBlockHashR
from cryptoapis.model.list_transactions_by_block_hash_r_data import ListTransactionsByBlockHashRData
from cryptoapis.model.list_transactions_by_block_hash_ri import ListTransactionsByBlockHashRI
from cryptoapis.model.list_transactions_by_block_hash_ribs import ListTransactionsByBlockHashRIBS
from cryptoapis.model.list_transactions_by_block_hash_ribsb import ListTransactionsByBlockHashRIBSB
from cryptoapis.model.list_transactions_by_block_hash_ribsbc import ListTransactionsByBlockHashRIBSBC
from cryptoapis.model.list_transactions_by_block_hash_ribsbc_script_pub_key import ListTransactionsByBlockHashRIBSBCScriptPubKey
from cryptoapis.model.list_transactions_by_block_hash_ribsbc_vin import ListTransactionsByBlockHashRIBSBCVin
from cryptoapis.model.list_transactions_by_block_hash_ribsbc_vout import ListTransactionsByBlockHashRIBSBCVout
from cryptoapis.model.list_transactions_by_block_hash_ribsb_vin import ListTransactionsByBlockHashRIBSBVin
from cryptoapis.model.list_transactions_by_block_hash_ribsd import ListTransactionsByBlockHashRIBSD
from cryptoapis.model.list_transactions_by_block_hash_ribsd2 import ListTransactionsByBlockHashRIBSD2
from cryptoapis.model.list_transactions_by_block_hash_ribsd2_script_pub_key import ListTransactionsByBlockHashRIBSD2ScriptPubKey
from cryptoapis.model.list_transactions_by_block_hash_ribsd2_script_sig import ListTransactionsByBlockHashRIBSD2ScriptSig
from cryptoapis.model.list_transactions_by_block_hash_ribsd2_vin import ListTransactionsByBlockHashRIBSD2Vin
from cryptoapis.model.list_transactions_by_block_hash_ribsd2_vout import ListTransactionsByBlockHashRIBSD2Vout
from cryptoapis.model.list_transactions_by_block_hash_ribsd_script_pub_key import ListTransactionsByBlockHashRIBSDScriptPubKey
from cryptoapis.model.list_transactions_by_block_hash_ribsd_vin import ListTransactionsByBlockHashRIBSDVin
from cryptoapis.model.list_transactions_by_block_hash_ribsd_vout import ListTransactionsByBlockHashRIBSDVout
from cryptoapis.model.list_transactions_by_block_hash_ribse import ListTransactionsByBlockHashRIBSE
from cryptoapis.model.list_transactions_by_block_hash_ribsec import ListTransactionsByBlockHashRIBSEC
from cryptoapis.model.list_transactions_by_block_hash_ribse_gas_price import ListTransactionsByBlockHashRIBSEGasPrice
from cryptoapis.model.list_transactions_by_block_hash_ribsl import ListTransactionsByBlockHashRIBSL
from cryptoapis.model.list_transactions_by_block_hash_ribsl_script_pub_key import ListTransactionsByBlockHashRIBSLScriptPubKey
from cryptoapis.model.list_transactions_by_block_hash_ribsl_vin import ListTransactionsByBlockHashRIBSLVin
from cryptoapis.model.list_transactions_by_block_hash_ribsl_vout import ListTransactionsByBlockHashRIBSLVout
from cryptoapis.model.list_transactions_by_block_hash_ri_fee import ListTransactionsByBlockHashRIFee
from cryptoapis.model.list_transactions_by_block_hash_ri_recipients import ListTransactionsByBlockHashRIRecipients
from cryptoapis.model.list_transactions_by_block_hash_ri_senders import ListTransactionsByBlockHashRISenders
from cryptoapis.model.list_transactions_by_block_height_r import ListTransactionsByBlockHeightR
from cryptoapis.model.list_transactions_by_block_height_r_data import ListTransactionsByBlockHeightRData
from cryptoapis.model.list_transactions_by_block_height_ri import ListTransactionsByBlockHeightRI
from cryptoapis.model.list_transactions_by_block_height_ribs import ListTransactionsByBlockHeightRIBS
from cryptoapis.model.list_transactions_by_block_height_ribsb import ListTransactionsByBlockHeightRIBSB
from cryptoapis.model.list_transactions_by_block_height_ribsbc import ListTransactionsByBlockHeightRIBSBC
from cryptoapis.model.list_transactions_by_block_height_ribsb_script_pub_key import ListTransactionsByBlockHeightRIBSBScriptPubKey
from cryptoapis.model.list_transactions_by_block_height_ribsb_vout import ListTransactionsByBlockHeightRIBSBVout
from cryptoapis.model.list_transactions_by_block_height_ribsd import ListTransactionsByBlockHeightRIBSD
from cryptoapis.model.list_transactions_by_block_height_ribsd2 import ListTransactionsByBlockHeightRIBSD2
from cryptoapis.model.list_transactions_by_block_height_ribsd2_vin import ListTransactionsByBlockHeightRIBSD2Vin
from cryptoapis.model.list_transactions_by_block_height_ribsd_script_pub_key import ListTransactionsByBlockHeightRIBSDScriptPubKey
from cryptoapis.model.list_transactions_by_block_height_ribsd_script_sig import ListTransactionsByBlockHeightRIBSDScriptSig
from cryptoapis.model.list_transactions_by_block_height_ribsd_vin import ListTransactionsByBlockHeightRIBSDVin
from cryptoapis.model.list_transactions_by_block_height_ribsd_vout import ListTransactionsByBlockHeightRIBSDVout
from cryptoapis.model.list_transactions_by_block_height_ribse import ListTransactionsByBlockHeightRIBSE
from cryptoapis.model.list_transactions_by_block_height_ribsec import ListTransactionsByBlockHeightRIBSEC
from cryptoapis.model.list_transactions_by_block_height_ribsec_gas_price import ListTransactionsByBlockHeightRIBSECGasPrice
from cryptoapis.model.list_transactions_by_block_height_ribsl import ListTransactionsByBlockHeightRIBSL
from cryptoapis.model.list_transactions_by_block_height_ribsl_script_pub_key import ListTransactionsByBlockHeightRIBSLScriptPubKey
from cryptoapis.model.list_transactions_by_block_height_ribsl_script_sig import ListTransactionsByBlockHeightRIBSLScriptSig
from cryptoapis.model.list_transactions_by_block_height_ribsl_vin import ListTransactionsByBlockHeightRIBSLVin
from cryptoapis.model.list_transactions_by_block_height_ribsl_vout import ListTransactionsByBlockHeightRIBSLVout
from cryptoapis.model.list_transactions_by_block_height_ri_fee import ListTransactionsByBlockHeightRIFee
from cryptoapis.model.list_unconfirmed_omni_transactions_by_address_r import ListUnconfirmedOmniTransactionsByAddressR
from cryptoapis.model.list_unconfirmed_omni_transactions_by_address_r_data import ListUnconfirmedOmniTransactionsByAddressRData
from cryptoapis.model.list_unconfirmed_omni_transactions_by_address_ri import ListUnconfirmedOmniTransactionsByAddressRI
from cryptoapis.model.list_unconfirmed_omni_transactions_by_address_ri_fee import ListUnconfirmedOmniTransactionsByAddressRIFee
from cryptoapis.model.list_unconfirmed_omni_transactions_by_address_ri_senders import ListUnconfirmedOmniTransactionsByAddressRISenders
from cryptoapis.model.list_unconfirmed_omni_transactions_by_property_idr import ListUnconfirmedOmniTransactionsByPropertyIDR
from cryptoapis.model.list_unconfirmed_omni_transactions_by_property_idr_data import ListUnconfirmedOmniTransactionsByPropertyIDRData
from cryptoapis.model.list_unconfirmed_omni_transactions_by_property_idri import ListUnconfirmedOmniTransactionsByPropertyIDRI
from cryptoapis.model.list_xrp_ripple_transactions_by_address_r import ListXRPRippleTransactionsByAddressR
from cryptoapis.model.list_xrp_ripple_transactions_by_address_r_data import ListXRPRippleTransactionsByAddressRData
from cryptoapis.model.list_xrp_ripple_transactions_by_address_ri import ListXRPRippleTransactionsByAddressRI
from cryptoapis.model.list_xrp_ripple_transactions_by_address_ri_fee import ListXRPRippleTransactionsByAddressRIFee
from cryptoapis.model.list_xrp_ripple_transactions_by_address_ri_offer import ListXRPRippleTransactionsByAddressRIOffer
from cryptoapis.model.list_xrp_ripple_transactions_by_address_ri_receive import ListXRPRippleTransactionsByAddressRIReceive
from cryptoapis.model.list_xrp_ripple_transactions_by_address_ri_value import ListXRPRippleTransactionsByAddressRIValue
from cryptoapis.model.list_xrp_ripple_transactions_by_block_hash_r import ListXRPRippleTransactionsByBlockHashR
from cryptoapis.model.list_xrp_ripple_transactions_by_block_hash_r_data import ListXRPRippleTransactionsByBlockHashRData
from cryptoapis.model.list_xrp_ripple_transactions_by_block_hash_ri import ListXRPRippleTransactionsByBlockHashRI
from cryptoapis.model.list_xrp_ripple_transactions_by_block_hash_ri_fee import ListXRPRippleTransactionsByBlockHashRIFee
from cryptoapis.model.list_xrp_ripple_transactions_by_block_hash_ri_offer import ListXRPRippleTransactionsByBlockHashRIOffer
from cryptoapis.model.list_xrp_ripple_transactions_by_block_hash_ri_receive import ListXRPRippleTransactionsByBlockHashRIReceive
from cryptoapis.model.list_xrp_ripple_transactions_by_block_hash_ri_recipients import ListXRPRippleTransactionsByBlockHashRIRecipients
from cryptoapis.model.list_xrp_ripple_transactions_by_block_hash_ri_senders import ListXRPRippleTransactionsByBlockHashRISenders
from cryptoapis.model.list_xrp_ripple_transactions_by_block_hash_ri_value import ListXRPRippleTransactionsByBlockHashRIValue
from cryptoapis.model.list_xrp_ripple_transactions_by_block_height_r import ListXRPRippleTransactionsByBlockHeightR
from cryptoapis.model.list_xrp_ripple_transactions_by_block_height_r_data import ListXRPRippleTransactionsByBlockHeightRData
from cryptoapis.model.list_xrp_ripple_transactions_by_block_height_ri import ListXRPRippleTransactionsByBlockHeightRI
from cryptoapis.model.list_xrp_ripple_transactions_by_block_height_ri_fee import ListXRPRippleTransactionsByBlockHeightRIFee
from cryptoapis.model.list_xrp_ripple_transactions_by_block_height_ri_offer import ListXRPRippleTransactionsByBlockHeightRIOffer
from cryptoapis.model.list_xrp_ripple_transactions_by_block_height_ri_receive import ListXRPRippleTransactionsByBlockHeightRIReceive
from cryptoapis.model.list_xrp_ripple_transactions_by_block_height_ri_recipients import ListXRPRippleTransactionsByBlockHeightRIRecipients
from cryptoapis.model.list_xrp_ripple_transactions_by_block_height_ri_senders import ListXRPRippleTransactionsByBlockHeightRISenders
from cryptoapis.model.list_xrp_ripple_transactions_by_block_height_ri_value import ListXRPRippleTransactionsByBlockHeightRIValue
from cryptoapis.model.list_zilliqa_transactions_by_address_r import ListZilliqaTransactionsByAddressR
from cryptoapis.model.list_zilliqa_transactions_by_address_r_data import ListZilliqaTransactionsByAddressRData
from cryptoapis.model.list_zilliqa_transactions_by_address_ri import ListZilliqaTransactionsByAddressRI
from cryptoapis.model.list_zilliqa_transactions_by_address_ri_recipients import ListZilliqaTransactionsByAddressRIRecipients
from cryptoapis.model.list_zilliqa_transactions_by_address_ri_senders import ListZilliqaTransactionsByAddressRISenders
from cryptoapis.model.list_zilliqa_transactions_by_block_hash_r import ListZilliqaTransactionsByBlockHashR
from cryptoapis.model.list_zilliqa_transactions_by_block_hash_r_data import ListZilliqaTransactionsByBlockHashRData
from cryptoapis.model.list_zilliqa_transactions_by_block_hash_ri import ListZilliqaTransactionsByBlockHashRI
from cryptoapis.model.list_zilliqa_transactions_by_block_height_r import ListZilliqaTransactionsByBlockHeightR
from cryptoapis.model.list_zilliqa_transactions_by_block_height_r_data import ListZilliqaTransactionsByBlockHeightRData
from cryptoapis.model.list_zilliqa_transactions_by_block_height_ri import ListZilliqaTransactionsByBlockHeightRI
from cryptoapis.model.mined_transaction_r import MinedTransactionR
from cryptoapis.model.mined_transaction_rb import MinedTransactionRB
from cryptoapis.model.mined_transaction_rb_data import MinedTransactionRBData
from cryptoapis.model.mined_transaction_rb_data_item import MinedTransactionRBDataItem
from cryptoapis.model.mined_transaction_r_data import MinedTransactionRData
from cryptoapis.model.mined_transaction_ri import MinedTransactionRI
from cryptoapis.model.missing_api_key import MissingApiKey
from cryptoapis.model.missing_api_key_error import MissingApiKeyError
from cryptoapis.model.new_block_r import NewBlockR
from cryptoapis.model.new_block_rb import NewBlockRB
from cryptoapis.model.new_block_rb_data import NewBlockRBData
from cryptoapis.model.new_block_rb_data_item import NewBlockRBDataItem
from cryptoapis.model.new_block_r_data import NewBlockRData
from cryptoapis.model.new_block_ri import NewBlockRI
from cryptoapis.model.new_confirmed_coins_transactions_and_each_confirmation_r import NewConfirmedCoinsTransactionsAndEachConfirmationR
from cryptoapis.model.new_confirmed_coins_transactions_and_each_confirmation_rb import NewConfirmedCoinsTransactionsAndEachConfirmationRB
from cryptoapis.model.new_confirmed_coins_transactions_and_each_confirmation_rb_data import NewConfirmedCoinsTransactionsAndEachConfirmationRBData
from cryptoapis.model.new_confirmed_coins_transactions_and_each_confirmation_rb_data_item import NewConfirmedCoinsTransactionsAndEachConfirmationRBDataItem
from cryptoapis.model.new_confirmed_coins_transactions_and_each_confirmation_r_data import NewConfirmedCoinsTransactionsAndEachConfirmationRData
from cryptoapis.model.new_confirmed_coins_transactions_and_each_confirmation_ri import NewConfirmedCoinsTransactionsAndEachConfirmationRI
from cryptoapis.model.new_confirmed_coins_transactions_r import NewConfirmedCoinsTransactionsR
from cryptoapis.model.new_confirmed_coins_transactions_rb import NewConfirmedCoinsTransactionsRB
from cryptoapis.model.new_confirmed_coins_transactions_rb_data import NewConfirmedCoinsTransactionsRBData
from cryptoapis.model.new_confirmed_coins_transactions_rb_data_item import NewConfirmedCoinsTransactionsRBDataItem
from cryptoapis.model.new_confirmed_coins_transactions_r_data import NewConfirmedCoinsTransactionsRData
from cryptoapis.model.new_confirmed_coins_transactions_ri import NewConfirmedCoinsTransactionsRI
from cryptoapis.model.new_confirmed_internal_transactions_and_each_confirmation_r import NewConfirmedInternalTransactionsAndEachConfirmationR
from cryptoapis.model.new_confirmed_internal_transactions_and_each_confirmation_rb import NewConfirmedInternalTransactionsAndEachConfirmationRB
from cryptoapis.model.new_confirmed_internal_transactions_and_each_confirmation_rb_data import NewConfirmedInternalTransactionsAndEachConfirmationRBData
from cryptoapis.model.new_confirmed_internal_transactions_and_each_confirmation_rb_data_item import NewConfirmedInternalTransactionsAndEachConfirmationRBDataItem
from cryptoapis.model.new_confirmed_internal_transactions_and_each_confirmation_r_data import NewConfirmedInternalTransactionsAndEachConfirmationRData
from cryptoapis.model.new_confirmed_internal_transactions_and_each_confirmation_ri import NewConfirmedInternalTransactionsAndEachConfirmationRI
from cryptoapis.model.new_confirmed_internal_transactions_r import NewConfirmedInternalTransactionsR
from cryptoapis.model.new_confirmed_internal_transactions_rb import NewConfirmedInternalTransactionsRB
from cryptoapis.model.new_confirmed_internal_transactions_rb_data import NewConfirmedInternalTransactionsRBData
from cryptoapis.model.new_confirmed_internal_transactions_rb_data_item import NewConfirmedInternalTransactionsRBDataItem
from cryptoapis.model.new_confirmed_internal_transactions_r_data import NewConfirmedInternalTransactionsRData
from cryptoapis.model.new_confirmed_internal_transactions_ri import NewConfirmedInternalTransactionsRI
from cryptoapis.model.new_confirmed_tokens_transactions_and_each_confirmation_r import NewConfirmedTokensTransactionsAndEachConfirmationR
from cryptoapis.model.new_confirmed_tokens_transactions_and_each_confirmation_rb import NewConfirmedTokensTransactionsAndEachConfirmationRB
from cryptoapis.model.new_confirmed_tokens_transactions_and_each_confirmation_rb_data import NewConfirmedTokensTransactionsAndEachConfirmationRBData
from cryptoapis.model.new_confirmed_tokens_transactions_and_each_confirmation_rb_data_item import NewConfirmedTokensTransactionsAndEachConfirmationRBDataItem
from cryptoapis.model.new_confirmed_tokens_transactions_and_each_confirmation_r_data import NewConfirmedTokensTransactionsAndEachConfirmationRData
from cryptoapis.model.new_confirmed_tokens_transactions_and_each_confirmation_ri import NewConfirmedTokensTransactionsAndEachConfirmationRI
from cryptoapis.model.new_confirmed_tokens_transactions_r import NewConfirmedTokensTransactionsR
from cryptoapis.model.new_confirmed_tokens_transactions_rb import NewConfirmedTokensTransactionsRB
from cryptoapis.model.new_confirmed_tokens_transactions_r_data import NewConfirmedTokensTransactionsRData
from cryptoapis.model.new_confirmed_tokens_transactions_ri import NewConfirmedTokensTransactionsRI
from cryptoapis.model.new_unconfirmed_coins_transactions_r import NewUnconfirmedCoinsTransactionsR
from cryptoapis.model.new_unconfirmed_coins_transactions_rb import NewUnconfirmedCoinsTransactionsRB
from cryptoapis.model.new_unconfirmed_coins_transactions_rb_data import NewUnconfirmedCoinsTransactionsRBData
from cryptoapis.model.new_unconfirmed_coins_transactions_rb_data_item import NewUnconfirmedCoinsTransactionsRBDataItem
from cryptoapis.model.new_unconfirmed_coins_transactions_r_data import NewUnconfirmedCoinsTransactionsRData
from cryptoapis.model.new_unconfirmed_coins_transactions_ri import NewUnconfirmedCoinsTransactionsRI
from cryptoapis.model.new_unconfirmed_tokens_transactions_r import NewUnconfirmedTokensTransactionsR
from cryptoapis.model.new_unconfirmed_tokens_transactions_rb import NewUnconfirmedTokensTransactionsRB
from cryptoapis.model.new_unconfirmed_tokens_transactions_rb_data import NewUnconfirmedTokensTransactionsRBData
from cryptoapis.model.new_unconfirmed_tokens_transactions_rb_data_item import NewUnconfirmedTokensTransactionsRBDataItem
from cryptoapis.model.new_unconfirmed_tokens_transactions_r_data import NewUnconfirmedTokensTransactionsRData
from cryptoapis.model.new_unconfirmed_tokens_transactions_ri import NewUnconfirmedTokensTransactionsRI
from cryptoapis.model.request_limit_reached import RequestLimitReached
from cryptoapis.model.request_limit_reached_error import RequestLimitReachedError
from cryptoapis.model.resource_not_found import ResourceNotFound
from cryptoapis.model.resource_not_found_error import ResourceNotFoundError
from cryptoapis.model.sync_hd_wallet_x_pub_y_pub_z_pub_r import SyncHDWalletXPubYPubZPubR
from cryptoapis.model.sync_hd_wallet_x_pub_y_pub_z_pub_rb import SyncHDWalletXPubYPubZPubRB
from cryptoapis.model.sync_hd_wallet_x_pub_y_pub_z_pub_rb_data import SyncHDWalletXPubYPubZPubRBData
from cryptoapis.model.sync_hd_wallet_x_pub_y_pub_z_pub_rb_data_item import SyncHDWalletXPubYPubZPubRBDataItem
from cryptoapis.model.sync_hd_wallet_x_pub_y_pub_z_pub_r_data import SyncHDWalletXPubYPubZPubRData
from cryptoapis.model.sync_hd_wallet_x_pub_y_pub_z_pub_ri import SyncHDWalletXPubYPubZPubRI
from cryptoapis.model.tokens_forwarding_automations_limit_reached import TokensForwardingAutomationsLimitReached
from cryptoapis.model.tokens_forwarding_automations_limit_reached_error import TokensForwardingAutomationsLimitReachedError
from cryptoapis.model.tokens_forwarding_fail import TokensForwardingFail
from cryptoapis.model.tokens_forwarding_fail_data import TokensForwardingFailData
from cryptoapis.model.tokens_forwarding_fail_data_item import TokensForwardingFailDataItem
from cryptoapis.model.tokens_forwarding_success import TokensForwardingSuccess
from cryptoapis.model.tokens_forwarding_success_data import TokensForwardingSuccessData
from cryptoapis.model.tokens_forwarding_success_data_item import TokensForwardingSuccessDataItem
from cryptoapis.model.tokens_forwarding_success_ethereumerc20token import TokensForwardingSuccessEthereumerc20token
from cryptoapis.model.tokens_forwarding_success_ethereumerc721token import TokensForwardingSuccessEthereumerc721token
from cryptoapis.model.tokens_forwarding_success_omnilayertoken import TokensForwardingSuccessOmnilayertoken
from cryptoapis.model.tokens_forwarding_success_token import TokensForwardingSuccessToken
from cryptoapis.model.transaction_mined import TransactionMined
from cryptoapis.model.transaction_mined_data import TransactionMinedData
from cryptoapis.model.transaction_mined_data_item import TransactionMinedDataItem
from cryptoapis.model.transaction_mined_data_item_mined_in_block import TransactionMinedDataItemMinedInBlock
from cryptoapis.model.transaction_request_approve import TransactionRequestApprove
from cryptoapis.model.transaction_request_approve_data import TransactionRequestApproveData
from cryptoapis.model.transaction_request_approve_data_item import TransactionRequestApproveDataItem
from cryptoapis.model.transaction_request_broadcasted import TransactionRequestBroadcasted
from cryptoapis.model.transaction_request_broadcasted_data import TransactionRequestBroadcastedData
from cryptoapis.model.transaction_request_broadcasted_data_item import TransactionRequestBroadcastedDataItem
from cryptoapis.model.transaction_request_mined import TransactionRequestMined
from cryptoapis.model.transaction_request_mined_data import TransactionRequestMinedData
from cryptoapis.model.transaction_request_reject import TransactionRequestReject
from cryptoapis.model.transaction_request_reject_data import TransactionRequestRejectData
from cryptoapis.model.transaction_request_reject_data_item import TransactionRequestRejectDataItem
from cryptoapis.model.unexpected_server_error import UnexpectedServerError
from cryptoapis.model.unexpected_server_error_error import UnexpectedServerErrorError
from cryptoapis.model.unsupported_media_type import UnsupportedMediaType
from cryptoapis.model.unsupported_media_type_error import UnsupportedMediaTypeError
from cryptoapis.model.uri_not_found import UriNotFound
from cryptoapis.model.uri_not_found_error import UriNotFoundError
from cryptoapis.model.validate_address_r import ValidateAddressR
from cryptoapis.model.validate_address_rb import ValidateAddressRB
from cryptoapis.model.validate_address_rb_data import ValidateAddressRBData
from cryptoapis.model.validate_address_rb_data_item import ValidateAddressRBDataItem
from cryptoapis.model.validate_address_r_data import ValidateAddressRData
from cryptoapis.model.validate_address_ri import ValidateAddressRI
from cryptoapis.model.wallet_as_a_service_deposit_addresses_limit_reached import WalletAsAServiceDepositAddressesLimitReached
from cryptoapis.model.wallet_as_a_service_deposit_addresses_limit_reached_error import WalletAsAServiceDepositAddressesLimitReachedError
from cryptoapis.model.wallet_as_a_service_no_deposit_addresses_found import WalletAsAServiceNoDepositAddressesFound
from cryptoapis.model.wallet_as_a_service_no_deposit_addresses_found_error import WalletAsAServiceNoDepositAddressesFoundError
from cryptoapis.model.wallet_as_a_service_token_not_supported import WalletAsAServiceTokenNotSupported
from cryptoapis.model.wallet_as_a_service_token_not_supported_error import WalletAsAServiceTokenNotSupportedError
from cryptoapis.model.wallet_as_a_service_wallet_balance_not_enough import WalletAsAServiceWalletBalanceNotEnough
from cryptoapis.model.wallet_as_a_service_wallet_balance_not_enough_error import WalletAsAServiceWalletBalanceNotEnoughError
from cryptoapis.model.xpub_not_synced import XpubNotSynced
from cryptoapis.model.xpub_not_synced_error import XpubNotSyncedError
from cryptoapis.model.xpub_sync_in_progress import XpubSyncInProgress
from cryptoapis.model.xpub_sync_in_progress_error import XpubSyncInProgressError



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from cryptoapis.api_client import ApiClient, Endpoint as _Endpoint
from cryptoapis.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from cryptoapis.model.blockchain_data_transaction_not_found import BlockchainDataTransactionNotFound
from cryptoapis.model.feature_mainnets_not_allowed_for_plan import FeatureMainnetsNotAllowedForPlan
from cryptoapis.model.get_omni_transaction_details_by_transaction_id_txid_r import GetOmniTransactionDetailsByTransactionIDTxidR
from cryptoapis.model.get_unconfirmed_omni_transaction_by_transaction_id_txid_r import GetUnconfirmedOmniTransactionByTransactionIDTxidR
from cryptoapis.model.insufficient_credits import InsufficientCredits
from cryptoapis.model.invalid_api_key import InvalidApiKey
from cryptoapis.model.invalid_data import InvalidData
from cryptoapis.model.invalid_pagination import InvalidPagination
from cryptoapis.model.invalid_request_body_structure import InvalidRequestBodyStructure
from cryptoapis.model.list_omni_tokens_by_address_r import ListOmniTokensByAddressR
from cryptoapis.model.list_omni_transactions_by_address_r import ListOmniTransactionsByAddressR
from cryptoapis.model.list_omni_transactions_by_block_hash_r import ListOmniTransactionsByBlockHashR
from cryptoapis.model.list_omni_transactions_by_block_height_r import ListOmniTransactionsByBlockHeightR
from cryptoapis.model.list_unconfirmed_omni_transactions_by_address_r import ListUnconfirmedOmniTransactionsByAddressR
from cryptoapis.model.list_unconfirmed_omni_transactions_by_property_idr import ListUnconfirmedOmniTransactionsByPropertyIDR
from cryptoapis.model.request_limit_reached import RequestLimitReached
from cryptoapis.model.unexpected_server_error import UnexpectedServerError
from cryptoapis.model.unsupported_media_type import UnsupportedMediaType


class OmniLayerApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __get_omni_transaction_details_by_transaction_id__txid(
            self,
            network,
            transaction_id,
            blockchain="bitcoin",
            **kwargs
        ):
            """Get Omni Transaction Details By Transaction ID (Txid)  # noqa: E501

            Through this endpoint customers can obtain details about an Omni transaction by the transaction's unique identifier. The transaction can return information such as hash, height, time of creation in Unix timestamp, etc.  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_omni_transaction_details_by_transaction_id__txid(network, transaction_id, blockchain="bitcoin", async_req=True)
            >>> result = thread.get()

            Args:
                network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\", \"rinkeby\" are test networks.
                transaction_id (str): Represents the unique identifier of a transaction, i.e. it could be `transactionId` in UTXO-based protocols like Bitcoin, and transaction `hash` in Ethereum blockchain.
                blockchain (str): Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.. defaults to "bitcoin", must be one of ["bitcoin"]

            Keyword Args:
                context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                GetOmniTransactionDetailsByTransactionIDTxidR
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['network'] = \
                network
            kwargs['blockchain'] = \
                blockchain
            kwargs['transaction_id'] = \
                transaction_id
            return self.call_with_http_info(**kwargs)

        self.get_omni_transaction_details_by_transaction_id__txid = _Endpoint(
            settings={
                'response_type': (GetOmniTransactionDetailsByTransactionIDTxidR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/blockchain-data/{blockchain}/{network}/omni/transactions/{transactionId}',
                'operation_id': 'get_omni_transaction_details_by_transaction_id__txid',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'network',
                    'blockchain',
                    'transaction_id',
                    'context',
                ],
                'required': [
                    'network',
                    'blockchain',
                    'transaction_id',
                ],
                'nullable': [
                ],
                'enum': [
                    'network',
                    'blockchain',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet"
                    },
                    ('blockchain',): {

                        "BITCOIN": "bitcoin"
                    },
                },
                'openapi_types': {
                    'network':
                        (str,),
                    'blockchain':
                        (str,),
                    'transaction_id':
                        (str,),
                    'context':
                        (str,),
                },
                'attribute_map': {
                    'network': 'network',
                    'blockchain': 'blockchain',
                    'transaction_id': 'transactionId',
                    'context': 'context',
                },
                'location_map': {
                    'network': 'path',
                    'blockchain': 'path',
                    'transaction_id': 'path',
                    'context': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_omni_transaction_details_by_transaction_id__txid
        )

        def __get_unconfirmed_omni_transaction_by_transaction_id__txid(
            self,
            network,
            transaction_id,
            blockchain="bitcoin",
            **kwargs
        ):
            """Get Unconfirmed Omni Transaction By Transaction ID (Txid)  # noqa: E501

            Through this endpoint customers can obtain information on unconfirmed Omni transactions by an attribute `transactionId`. The transaction can have information such as hash, height, time of creation in Unix timestamp, etc.    Unconfirmed transactions are usually put in the Mempool and await verification so that they can be added to a block.  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_unconfirmed_omni_transaction_by_transaction_id__txid(network, transaction_id, blockchain="bitcoin", async_req=True)
            >>> result = thread.get()

            Args:
                network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\", \"rinkeby\" are test networks.
                transaction_id (str): Represents the unique identifier of a transaction, i.e. it could be `transactionId` in UTXO-based protocols like Bitcoin, and transaction `hash` in Ethereum blockchain.
                blockchain (str): Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.. defaults to "bitcoin", must be one of ["bitcoin"]

            Keyword Args:
                context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                GetUnconfirmedOmniTransactionByTransactionIDTxidR
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['network'] = \
                network
            kwargs['blockchain'] = \
                blockchain
            kwargs['transaction_id'] = \
                transaction_id
            return self.call_with_http_info(**kwargs)

        self.get_unconfirmed_omni_transaction_by_transaction_id__txid = _Endpoint(
            settings={
                'response_type': (GetUnconfirmedOmniTransactionByTransactionIDTxidR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/blockchain-data/{blockchain}/{network}/omni/transactions-unconfirmed/{transactionId}',
                'operation_id': 'get_unconfirmed_omni_transaction_by_transaction_id__txid',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'network',
                    'blockchain',
                    'transaction_id',
                    'context',
                ],
                'required': [
                    'network',
                    'blockchain',
                    'transaction_id',
                ],
                'nullable': [
                ],
                'enum': [
                    'network',
                    'blockchain',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet"
                    },
                    ('blockchain',): {

                        "BITCOIN": "bitcoin"
                    },
                },
                'openapi_types': {
                    'network':
                        (str,),
                    'blockchain':
                        (str,),
                    'transaction_id':
                        (str,),
                    'context':
                        (str,),
                },
                'attribute_map': {
                    'network': 'network',
                    'blockchain': 'blockchain',
                    'transaction_id': 'transactionId',
                    'context': 'context',
                },
                'location_map': {
                    'network': 'path',
                    'blockchain': 'path',
                    'transaction_id': 'path',
                    'context': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_unconfirmed_omni_transaction_by_transaction_id__txid
        )

        def __list_omni_tokens_by_address(
            self,
            network,
            address,
            blockchain="bitcoin",
            **kwargs
        ):
            """List Omni Tokens By Address  # noqa: E501

            Through this endpoint the customer can receive basic information about a given Omni address based on confirmed/synced blocks only. In the case where there are any incoming or outgoing **unconfirmed** transactions for the specific address, they **will not** be counted or calculated here.    {note}Please note that listing data from the same type will apply pagination on the results.{/note}  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_omni_tokens_by_address(network, address, blockchain="bitcoin", async_req=True)
            >>> result = thread.get()

            Args:
                network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\", \"rinkeby\" are test networks.
                address (str): Represents the public address, which is a compressed and shortened form of a public key.
                blockchain (str): Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.. defaults to "bitcoin", must be one of ["bitcoin"]

            Keyword Args:
                context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListOmniTokensByAddressR
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['network'] = \
                network
            kwargs['blockchain'] = \
                blockchain
            kwargs['address'] = \
                address
            return self.call_with_http_info(**kwargs)

        self.list_omni_tokens_by_address = _Endpoint(
            settings={
                'response_type': (ListOmniTokensByAddressR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/blockchain-data/{blockchain}/{network}/omni/addresses/{address}',
                'operation_id': 'list_omni_tokens_by_address',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'network',
                    'blockchain',
                    'address',
                    'context',
                ],
                'required': [
                    'network',
                    'blockchain',
                    'address',
                ],
                'nullable': [
                ],
                'enum': [
                    'network',
                    'blockchain',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet"
                    },
                    ('blockchain',): {

                        "BITCOIN": "bitcoin"
                    },
                },
                'openapi_types': {
                    'network':
                        (str,),
                    'blockchain':
                        (str,),
                    'address':
                        (str,),
                    'context':
                        (str,),
                },
                'attribute_map': {
                    'network': 'network',
                    'blockchain': 'blockchain',
                    'address': 'address',
                    'context': 'context',
                },
                'location_map': {
                    'network': 'path',
                    'blockchain': 'path',
                    'address': 'path',
                    'context': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__list_omni_tokens_by_address
        )

        def __list_omni_transactions_by_address(
            self,
            network,
            address,
            blockchain="bitcoin",
            **kwargs
        ):
            """List Omni Transactions By Address  # noqa: E501

            This endpoint will list Omni transactions by an attribute `address`. The transactions listed will detail additional information such as hash, height, time of creation in Unix timestamp, etc.    {note}Please note that listing data from the same type will apply pagination on the results.{/note}  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_omni_transactions_by_address(network, address, blockchain="bitcoin", async_req=True)
            >>> result = thread.get()

            Args:
                network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\", \"rinkeby\" are test networks.
                address (str): Represents the public address, which is a compressed and shortened form of a public key.
                blockchain (str): Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.. defaults to "bitcoin", must be one of ["bitcoin"]

            Keyword Args:
                context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
                limit (int): Defines how many items should be returned in the response per page basis.. [optional] if omitted the server will use the default value of 50
                offset (int): The starting index of the response items, i.e. where the response should start listing the returned items.. [optional] if omitted the server will use the default value of 0
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListOmniTransactionsByAddressR
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['network'] = \
                network
            kwargs['blockchain'] = \
                blockchain
            kwargs['address'] = \
                address
            return self.call_with_http_info(**kwargs)

        self.list_omni_transactions_by_address = _Endpoint(
            settings={
                'response_type': (ListOmniTransactionsByAddressR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/blockchain-data/{blockchain}/{network}/omni/addresses/{address}/transactions',
                'operation_id': 'list_omni_transactions_by_address',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'network',
                    'blockchain',
                    'address',
                    'context',
                    'limit',
                    'offset',
                ],
                'required': [
                    'network',
                    'blockchain',
                    'address',
                ],
                'nullable': [
                ],
                'enum': [
                    'network',
                    'blockchain',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet"
                    },
                    ('blockchain',): {

                        "BITCOIN": "bitcoin"
                    },
                },
                'openapi_types': {
                    'network':
                        (str,),
                    'blockchain':
                        (str,),
                    'address':
                        (str,),
                    'context':
                        (str,),
                    'limit':
                        (int,),
                    'offset':
                        (int,),
                },
                'attribute_map': {
                    'network': 'network',
                    'blockchain': 'blockchain',
                    'address': 'address',
                    'context': 'context',
                    'limit': 'limit',
                    'offset': 'offset',
                },
                'location_map': {
                    'network': 'path',
                    'blockchain': 'path',
                    'address': 'path',
                    'context': 'query',
                    'limit': 'query',
                    'offset': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__list_omni_transactions_by_address
        )

        def __list_omni_transactions_by_block_hash(
            self,
            network,
            block_hash,
            blockchain="bitcoin",
            **kwargs
        ):
            """List Omni Transactions By Block Hash  # noqa: E501

            This endpoint will list Omni transactions by an attribute `transactionHash`. The transactions listed will detail additional information such as addresses, height, time of creation in Unix timestamp, etc.    {note}Please note that listing data from the same type will apply pagination on the results.{/note}  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_omni_transactions_by_block_hash(network, block_hash, blockchain="bitcoin", async_req=True)
            >>> result = thread.get()

            Args:
                network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\", \"rinkeby\" are test networks.
                block_hash (str): Represents the hash of the block, which is its unique identifier. It represents a cryptographic digital fingerprint made by hashing the block header twice through the SHA256 algorithm.
                blockchain (str): Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.. defaults to "bitcoin", must be one of ["bitcoin"]

            Keyword Args:
                context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
                limit (int): Defines how many items should be returned in the response per page basis.. [optional] if omitted the server will use the default value of 50
                offset (int): The starting index of the response items, i.e. where the response should start listing the returned items.. [optional] if omitted the server will use the default value of 0
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListOmniTransactionsByBlockHashR
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['network'] = \
                network
            kwargs['blockchain'] = \
                blockchain
            kwargs['block_hash'] = \
                block_hash
            return self.call_with_http_info(**kwargs)

        self.list_omni_transactions_by_block_hash = _Endpoint(
            settings={
                'response_type': (ListOmniTransactionsByBlockHashR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/blockchain-data/{blockchain}/{network}/omni/blocks/hash/{blockHash}/transactions',
                'operation_id': 'list_omni_transactions_by_block_hash',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'network',
                    'blockchain',
                    'block_hash',
                    'context',
                    'limit',
                    'offset',
                ],
                'required': [
                    'network',
                    'blockchain',
                    'block_hash',
                ],
                'nullable': [
                ],
                'enum': [
                    'network',
                    'blockchain',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet"
                    },
                    ('blockchain',): {

                        "BITCOIN": "bitcoin"
                    },
                },
                'openapi_types': {
                    'network':
                        (str,),
                    'blockchain':
                        (str,),
                    'block_hash':
                        (str,),
                    'context':
                        (str,),
                    'limit':
                        (int,),
                    'offset':
                        (int,),
                },
                'attribute_map': {
                    'network': 'network',
                    'blockchain': 'blockchain',
                    'block_hash': 'blockHash',
                    'context': 'context',
                    'limit': 'limit',
                    'offset': 'offset',
                },
                'location_map': {
                    'network': 'path',
                    'blockchain': 'path',
                    'block_hash': 'path',
                    'context': 'query',
                    'limit': 'query',
                    'offset': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__list_omni_transactions_by_block_hash
        )

        def __list_omni_transactions_by_block_height(
            self,
            network,
            block_height,
            blockchain="bitcoin",
            **kwargs
        ):
            """List Omni Transactions By Block Height  # noqa: E501

            This endpoint will list Omni transactions by an attribute `blockHeight`. The transactions listed will detail additional information such as hash, addresses, time of creation in Unix timestamp, etc.    {note}Please note that listing data from the same type will apply pagination on the results.{/note}  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_omni_transactions_by_block_height(network, block_height, blockchain="bitcoin", async_req=True)
            >>> result = thread.get()

            Args:
                network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\", \"rinkeby\" are test networks.
                block_height (str): Represents the number of blocks in the blockchain preceding this specific block. Block numbers have no gaps. A blockchain usually starts with block 0 called the \"Genesis block\".
                blockchain (str): Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.. defaults to "bitcoin", must be one of ["bitcoin"]

            Keyword Args:
                context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
                limit (int): Defines how many items should be returned in the response per page basis.. [optional] if omitted the server will use the default value of 50
                offset (int): The starting index of the response items, i.e. where the response should start listing the returned items.. [optional] if omitted the server will use the default value of 0
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListOmniTransactionsByBlockHeightR
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['network'] = \
                network
            kwargs['blockchain'] = \
                blockchain
            kwargs['block_height'] = \
                block_height
            return self.call_with_http_info(**kwargs)

        self.list_omni_transactions_by_block_height = _Endpoint(
            settings={
                'response_type': (ListOmniTransactionsByBlockHeightR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/blockchain-data/{blockchain}/{network}/omni/blocks/height/{blockHeight}/transactions',
                'operation_id': 'list_omni_transactions_by_block_height',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'network',
                    'blockchain',
                    'block_height',
                    'context',
                    'limit',
                    'offset',
                ],
                'required': [
                    'network',
                    'blockchain',
                    'block_height',
                ],
                'nullable': [
                ],
                'enum': [
                    'network',
                    'blockchain',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet"
                    },
                    ('blockchain',): {

                        "BITCOIN": "bitcoin"
                    },
                },
                'openapi_types': {
                    'network':
                        (str,),
                    'blockchain':
                        (str,),
                    'block_height':
                        (str,),
                    'context':
                        (str,),
                    'limit':
                        (int,),
                    'offset':
                        (int,),
                },
                'attribute_map': {
                    'network': 'network',
                    'blockchain': 'blockchain',
                    'block_height': 'blockHeight',
                    'context': 'context',
                    'limit': 'limit',
                    'offset': 'offset',
                },
                'location_map': {
                    'network': 'path',
                    'blockchain': 'path',
                    'block_height': 'path',
                    'context': 'query',
                    'limit': 'query',
                    'offset': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__list_omni_transactions_by_block_height
        )

        def __list_unconfirmed_omni_transactions_by_address(
            self,
            network,
            address,
            blockchain="bitcoin",
            **kwargs
        ):
            """List Unconfirmed Omni Transactions By Address  # noqa: E501

            This endpoint will list unconfirmed Omni transactions by an attribute `address`. The transactions listed will detail additional information such as hash, height, time of creation in Unix timestamp, etc.    Unconfirmed transactions are usually put in the Mempool and await verification so that they can be added to a block.    {note}Please note that listing data from the same type will apply pagination on the results.{/note}  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_unconfirmed_omni_transactions_by_address(network, address, blockchain="bitcoin", async_req=True)
            >>> result = thread.get()

            Args:
                network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\", \"rinkeby\" are test networks.
                address (str): Represents the public address, which is a compressed and shortened form of a public key.
                blockchain (str): Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.. defaults to "bitcoin", must be one of ["bitcoin"]

            Keyword Args:
                context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
                limit (int): Defines how many items should be returned in the response per page basis.. [optional] if omitted the server will use the default value of 50
                offset (int): The starting index of the response items, i.e. where the response should start listing the returned items.. [optional] if omitted the server will use the default value of 0
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListUnconfirmedOmniTransactionsByAddressR
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['network'] = \
                network
            kwargs['blockchain'] = \
                blockchain
            kwargs['address'] = \
                address
            return self.call_with_http_info(**kwargs)

        self.list_unconfirmed_omni_transactions_by_address = _Endpoint(
            settings={
                'response_type': (ListUnconfirmedOmniTransactionsByAddressR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/blockchain-data/{blockchain}/{network}/omni/address-transactions-unconfirmed/{address}',
                'operation_id': 'list_unconfirmed_omni_transactions_by_address',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'network',
                    'blockchain',
                    'address',
                    'context',
                    'limit',
                    'offset',
                ],
                'required': [
                    'network',
                    'blockchain',
                    'address',
                ],
                'nullable': [
                ],
                'enum': [
                    'network',
                    'blockchain',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet"
                    },
                    ('blockchain',): {

                        "BITCOIN": "bitcoin"
                    },
                },
                'openapi_types': {
                    'network':
                        (str,),
                    'blockchain':
                        (str,),
                    'address':
                        (str,),
                    'context':
                        (str,),
                    'limit':
                        (int,),
                    'offset':
                        (int,),
                },
                'attribute_map': {
                    'network': 'network',
                    'blockchain': 'blockchain',
                    'address': 'address',
                    'context': 'context',
                    'limit': 'limit',
                    'offset': 'offset',
                },
                'location_map': {
                    'network': 'path',
                    'blockchain': 'path',
                    'address': 'path',
                    'context': 'query',
                    'limit': 'query',
                    'offset': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__list_unconfirmed_omni_transactions_by_address
        )

        def __list_unconfirmed_omni_transactions_by_property_id(
            self,
            network,
            property_id,
            blockchain="bitcoin",
            **kwargs
        ):
            """List Unconfirmed Omni Transactions By Property ID  # noqa: E501

            This endpoint will list unconfirmed Omni transactions by an attribute `propertyId`. The transactions listed will detail additional information such as hash, height, time of creation in Unix timestamp, etc.    Unconfirmed transactions are usually put in the Mempool and await verification so that they can be added to a block.    {note}Please note that listing data from the same type will apply pagination on the results.{/note}  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_unconfirmed_omni_transactions_by_property_id(network, property_id, blockchain="bitcoin", async_req=True)
            >>> result = thread.get()

            Args:
                network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\", \"rinkeby\" are test networks.
                property_id (str): Represents the identifier of the tokens to send.
                blockchain (str): Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.. defaults to "bitcoin", must be one of ["bitcoin"]

            Keyword Args:
                context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
                limit (int): Defines how many items should be returned in the response per page basis.. [optional] if omitted the server will use the default value of 50
                offset (int): The starting index of the response items, i.e. where the response should start listing the returned items.. [optional] if omitted the server will use the default value of 0
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListUnconfirmedOmniTransactionsByPropertyIDR
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['network'] = \
                network
            kwargs['blockchain'] = \
                blockchain
            kwargs['property_id'] = \
                property_id
            return self.call_with_http_info(**kwargs)

        self.list_unconfirmed_omni_transactions_by_property_id = _Endpoint(
            settings={
                'response_type': (ListUnconfirmedOmniTransactionsByPropertyIDR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/blockchain-data/{blockchain}/{network}/omni/properties/{propertyId}/transactions',
                'operation_id': 'list_unconfirmed_omni_transactions_by_property_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'network',
                    'blockchain',
                    'property_id',
                    'context',
                    'limit',
                    'offset',
                ],
                'required': [
                    'network',
                    'blockchain',
                    'property_id',
                ],
                'nullable': [
                ],
                'enum': [
                    'network',
                    'blockchain',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet"
                    },
                    ('blockchain',): {

                        "BITCOIN": "bitcoin"
                    },
                },
                'openapi_types': {
                    'network':
                        (str,),
                    'blockchain':
                        (str,),
                    'property_id':
                        (str,),
                    'context':
                        (str,),
                    'limit':
                        (int,),
                    'offset':
                        (int,),
                },
                'attribute_map': {
                    'network': 'network',
                    'blockchain': 'blockchain',
                    'property_id': 'propertyId',
                    'context': 'context',
                    'limit': 'limit',
                    'offset': 'offset',
                },
                'location_map': {
                    'network': 'path',
                    'blockchain': 'path',
                    'property_id': 'path',
                    'context': 'query',
                    'limit': 'query',
                    'offset': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__list_unconfirmed_omni_transactions_by_property_id
        )
